@@ -176,6 +176,27 @@ if not vars().has_key('BOUNCE_ENV_SENDER'):
         BOUNCE_ENV_SENDER = '<>'
     else:
         BOUNCE_ENV_SENDER = ''
+
+# BOUNCE_TEXT_FILTER_INCOMING
+# Text for the failure notice returned to the sender when a 'bounce'
+# or 'reject' rule is matched in the incoming filter file.  Set to
+# None to disable notification.
+if not vars().has_key('BOUNCE_TEXT_FILTER_INCOMING'):
+    BOUNCE_TEXT_FILTER_INCOMING = """Message rejected by recipient."""
+
+# BOUNCE_TEXT_INVALID_CONFIRMATION
+# Text for the failure notice returned to the sender when a message is
+# sent to an invalid confirmation address.  Set to None to disable
+# notification.
+if not vars().has_key('BOUNCE_TEXT_INVALID_CONFIRMATION'):
+    BOUNCE_TEXT_INVALID_CONFIRMATION = """This confirmation address is invalid."""
+
+# BOUNCE_TEXT_NONEXISTENT_PENDING
+# Text for the failure notice returned to the sender when a
+# confirmation response arrives for a message which could not be
+# located.  Set to None to disable notification.
+if not vars().has_key('BOUNCE_TEXT_NONEXISTENT_PENDING'):
+    BOUNCE_TEXT_NONEXISTENT_PENDING = """Your original message could not be located."""
         
 # BARE_APPEND
 # Filename to which a recipient's e-mail address should be
@@ -212,12 +233,39 @@ if not vars().has_key('CONFIRM_CC'):
     CONFIRM_CC = None
 
 # CONFIRM_ACCEPT_NOTIFY
-# Set this variable to 0 if you do not want to generate confirmation
+# Set this variable to 0 if you do not want to generate any confirmation
 # acceptance notices.
 # Default is 1 (turned on)
 if not vars().has_key('CONFIRM_ACCEPT_NOTIFY'):
     CONFIRM_ACCEPT_NOTIFY = 1
 
+# CONFIRM_ACCEPT_TEXT_INITIAL
+# Text for the confirmation acceptance notice returned to the sender
+# when they initially confirm their original message causing it to
+# be delivered.  Set to None to disable notification.
+if not vars().has_key('CONFIRM_ACCEPT_TEXT_INITIAL'):
+    CONFIRM_ACCEPT_TEXT_INITIAL = \
+"""Your confirmation was accepted,
+and so your original message has been delivered."""
+
+# CONFIRM_ACCEPT_TEXT_ALREADY_CONFIRMED
+# Text for the confirmation acceptance notice returned to the sender
+# when they successfully confirm a message which has already been
+# confirmed.  Set to None to disable notification.
+if not vars().has_key('CONFIRM_ACCEPT_TEXT_ALREADY_CONFIRMED'):
+    CONFIRM_ACCEPT_TEXT_ALREADY_CONFIRMED = \
+"""Your original message has already been confirmed and delivered;
+you don't need to confirm it again."""
+
+# CONFIRM_ACCEPT_TEXT_ALREADY_RELEASED
+# Text for the confirmation acceptance notice returned to the sender
+# when they successfully confirm a message which has already been
+# manually released with tmda-pending.  Set to None to disable
+# notification.
+if not vars().has_key('CONFIRM_ACCEPT_TEXT_ALREADY_RELEASED'):
+    CONFIRM_ACCEPT_TEXT_ALREADY_RELEASED = \
+"""Your original message has already been released and delivered."""
+    
 # CONFIRM_ACCEPT_CC
 # An optional e-mail address which will be sent a copy of the
 # confirmation acceptance messages people send you.
@@ -232,17 +280,13 @@ if not vars().has_key('CONFIRM_ACCEPT_CC'):
 if not vars().has_key('CONFIRM_MAX_MESSAGE_SIZE'):
     CONFIRM_MAX_MESSAGE_SIZE = 50000
 
-# CONFIRM_ACCEPT_TEMPLATE
-# Full path to a custom template for confirmation acceptance notices.
-# Default is confirm_accept.txt in ../templates/.
-if not vars().has_key('CONFIRM_ACCEPT_TEMPLATE'):
-    CONFIRM_ACCEPT_TEMPLATE = PARENTDIR + '/templates/confirm_accept.txt'
-    
-# CONFIRM_REQUEST_TEMPLATE
-# Full path to a custom template for confirmation requests.
-# Default is confirm_request.txt in ../templates/.
-if not vars().has_key('CONFIRM_REQUEST_TEMPLATE'):
-    CONFIRM_REQUEST_TEMPLATE = PARENTDIR + '/templates/confirm_request.txt'
+# TEMPLATE_DIR
+# Full path to a directory containing custom TMDA templates.  Any
+# templates found in this directory will be used, otherwise the
+# default templates will be used.
+# No default.
+if not vars().has_key('TEMPLATE_DIR'):
+    TEMPLATE_DIR = None
 
 # DATED_TEMPLATE_VARS
 # Set this variable to 1 if you want to use 'dated' address variables
@@ -431,35 +475,43 @@ if not vars().has_key('LOGFILE_INCOMING'):
     LOGFILE_INCOMING = None
 
 # MESSAGE_FROM_STYLE
-# Specifies how `From' headers should look on when tagging outgoing
-# messages with tmda-inject.  There are three valid values:
+# Specifies how `From' headers should look when tagging outgoing
+# messages with tmda-sendmail.  There are two valid values:
 #
 #     "address"
 #           Just the address - king@grassland.com
 #
-#     "parens"
-#           king@grassland.com (Elvis Parsley)
-#
 #     "angles"
-#           "Elvis Parsley" <king@grassland.com>
-#
-#     "unquoted"
 #           Elvis Parsley <king@grassland.com>
-#           (only use if you know your fullname doesn't need
-#           double-quotes; see rfc2822 for clarification)
 #
 # Default is "angles".
 if not vars().has_key('MESSAGE_FROM_STYLE'):
     MESSAGE_FROM_STYLE = "angles"
 
+# DELIVERED_CACHE
+# Path to the cache file used to keep track of which messages have
+# already been delivered.
+#
+# Default is ~/.tmda/pending/.delivered_cache
+if not vars().has_key('DELIVERED_CACHE'):
+    DELIVERED_CACHE = os.path.join(DATADIR, 'pending', '.delivered_cache')
+
+# DELIVERED_CACHE_LEN
+# An integer which specifies the maximum number of entries held by
+# DELIVERED_CACHE.
+#
+# Default is 5000
+if not vars().has_key('DELIVERED_CACHE_LEN'):
+    DELIVERED_CACHE_LEN = 5000
+
 # PENDING_CACHE
 # Path to the cache file used when tmda-pending is invoked with the
 # --cache option.
 #
 # Default is ~/.tmda/pending/.msgcache
 if not vars().has_key('PENDING_CACHE'):
-    PENDING_CACHE = DATADIR + 'pending/.msgcache'
-
+    PENDING_CACHE = os.path.join(DATADIR, 'pending', '.msgcache')
+    
 # PENDING_CACHE_LEN
 # An integer which specifies the maximum number of entries held by
 # PENDING_CACHE.  Make sure this is greater than the number of
